@@ -26,6 +26,9 @@ class BackupJob {
     }
     
     public function processBackup($backupId) {
+        // Set generous time limit for backup operations (30 minutes)
+        set_time_limit(1800);
+
         $history = new BackupHistory($this->db, $backupId);
         $data = $history->getData();
         
@@ -173,10 +176,14 @@ class BackupJob {
             // Fall back to standard tar with gzip compression (level 6 for better speed/ratio balance)
             $command = "cd " . escapeshellarg(dirname($userDir)) . " && tar -cf " . escapeshellarg($tempFile) . " --use-compress-program='gzip -6' " . escapeshellarg($userName . "/" . $domainName);
         }
-        
-        exec($command, $output, $returnCode);
-        
-        if ($returnCode !== 0) {
+
+        // Execute with timeout wrapper (10 minutes for tar operations)
+        $timeoutCommand = "timeout 600 " . $command;
+        exec($timeoutCommand, $output, $returnCode);
+
+        if ($returnCode === 124) {
+            throw new Exception("Site archive creation timed out after 10 minutes");
+        } elseif ($returnCode !== 0) {
             throw new Exception("Failed to create site archive: " . implode("\n", $output));
         }
         
@@ -202,10 +209,14 @@ class BackupJob {
             // Fall back to standard tar with gzip compression (level 6 for better speed/ratio balance)
             $command = "cd " . escapeshellarg(dirname($userDir)) . " && tar -czf " . escapeshellarg($tempFile) . " --use-compress-program='gzip -6' " . escapeshellarg($userName . "/userfiles") . " 2>&1";
         }
-        
-        exec($command, $output, $returnCode);
-        
-        if ($returnCode !== 0) {
+
+        // Execute with timeout wrapper (10 minutes for tar/zip operations)
+        $timeoutCommand = "timeout 600 " . $command;
+        exec($timeoutCommand, $output, $returnCode);
+
+        if ($returnCode === 124) {
+            throw new Exception("Userfiles archive creation timed out after 10 minutes");
+        } elseif ($returnCode !== 0) {
             throw new Exception("Failed to create userfiles archive: " . implode("\n", $output));
         }
         
@@ -225,10 +236,14 @@ class BackupJob {
         
         // Create zip archive
         $command = "cd " . escapeshellarg(dirname($userDir)) . " && zip -r " . escapeshellarg($tempFile) . " " . escapeshellarg($userName . "/userfiles") . " 2>&1";
-        
-        exec($command, $output, $returnCode);
-        
-        if ($returnCode !== 0) {
+
+        // Execute with timeout wrapper (10 minutes for zip operations)
+        $timeoutCommand = "timeout 600 " . $command;
+        exec($timeoutCommand, $output, $returnCode);
+
+        if ($returnCode === 124) {
+            throw new Exception("Userfiles archive creation timed out after 10 minutes");
+        } elseif ($returnCode !== 0) {
             throw new Exception("Failed to create userfiles archive: " . implode("\n", $output));
         }
         
@@ -240,7 +255,8 @@ class BackupJob {
     
     private function createDatabaseDump($database, $tempFile) {
         // Validate database name for security (prevent SQL injection and command injection)
-        if (!preg_match('/^[a-zA-Z0-9_]+$/', $database)) {
+        // Allow alphanumeric characters, underscores, and hyphens (common in WordPress database names)
+        if (!preg_match('/^[a-zA-Z0-9_-]+$/', $database)) {
             throw new Exception("Invalid database name format");
         }
 
@@ -276,10 +292,17 @@ class BackupJob {
                   " --add-drop-database --create-options --complete-insert" .
                   " --databases " . escapeshellarg($database) . 
                   " > " . escapeshellarg($tempSqlFile) . " 2>&1";
-        
-        exec($command, $output, $returnCode);
-        
-        if ($returnCode !== 0) {
+        // Execute with timeout wrapper (10 minutes for database dumps)
+        $timeoutCommand = "timeout 600 " . $command;
+        exec($timeoutCommand, $output, $returnCode);
+
+        if ($returnCode === 124) {
+            // Clean up temp file
+            if (file_exists($tempSqlFile)) {
+                unlink($tempSqlFile);
+            }
+            throw new Exception("Database dump timed out after 10 minutes");
+        } elseif ($returnCode !== 0) {
             // Clean up temp file
             if (file_exists($tempSqlFile)) {
                 unlink($tempSqlFile);
@@ -299,14 +322,18 @@ class BackupJob {
         } else {
             $gzipCommand = "gzip -6 -c " . escapeshellarg($tempSqlFile) . " > " . escapeshellarg($tempFile);
         }
-        exec($gzipCommand, $gzipOutput, $gzipReturn);
-        
+
+        // Execute with timeout wrapper (10 minutes for compression)
+        $timeoutGzipCommand = "timeout 600 " . $gzipCommand;
+        exec($timeoutGzipCommand, $gzipOutput, $gzipReturn);
+
         // Clean up temp SQL file
         if (file_exists($tempSqlFile)) {
             unlink($tempSqlFile);
         }
-        
-        if ($gzipReturn !== 0) {
+        if ($gzipReturn === 124) {
+            throw new Exception("SQL dump compression timed out after 10 minutes");
+        } elseif ($gzipReturn !== 0) {
             throw new Exception("Failed to compress database dump: " . implode("\n", $gzipOutput));
         }
         
@@ -365,9 +392,13 @@ class BackupJob {
             $filesArg = implode(' ', array_map('escapeshellarg', $filesToArchive));
             $command = "cd " . escapeshellarg($tempWorkDir) . " && tar -czf " . escapeshellarg($tempFile) . " " . $filesArg;
 
-            exec($command, $output, $returnCode);
+            // Execute with timeout wrapper (10 minutes for WordPress archive)
+            $timeoutCommand = "timeout 600 " . $command;
+            exec($timeoutCommand, $output, $returnCode);
 
-            if ($returnCode !== 0) {
+            if ($returnCode === 124) {
+                throw new Exception("WordPress archive creation timed out after 10 minutes");
+            } elseif ($returnCode !== 0) {
                 throw new Exception("Failed to create WordPress archive: " . implode("\n", $output));
             }
 
@@ -399,9 +430,13 @@ class BackupJob {
             $command = "cd " . escapeshellarg(dirname($userDir)) . " && tar -czf " . escapeshellarg($tempFile) . " " . escapeshellarg($userName . "/" . $domainName);
         }
 
-        exec($command, $output, $returnCode);
+        // Execute with timeout wrapper (10 minutes for tar operations)
+        $timeoutCommand = "timeout 600 " . $command;
+        exec($timeoutCommand, $output, $returnCode);
 
-        if ($returnCode !== 0) {
+        if ($returnCode === 124) {
+            throw new Exception("Site archive creation timed out after 10 minutes");
+        } elseif ($returnCode !== 0) {
             throw new Exception("Failed to create site archive: " . implode("\n", $output));
         }
 
